%% Import data
Sheet = ["Nordic 1" "Nordic 2" "Nordic 3" "Nordic 4" "Nordic 5"];
for i = 1:5
    Data{i} = readtable("EMG Nordic.xlsx","Sheet",Sheet(i));
end


%% Plot raw data
Muscles = ["R Biceps" "R Semi" "L Biceps" "L Semi"];
for i = 1:5
    Name = strcat(Muscles," [V]");
    figure;
    stack = stackedplot(Data{i}(:,2:5),'Title',Sheet(i),'DisplayLabels',Name(1:4));
    stack.AxesProperties(1).YLimits = [-2 2]; % Lose tick labels !!
    stack.AxesProperties(2).YLimits = [-2 2];
    stack.AxesProperties(3).YLimits = [-2 2];
    stack.AxesProperties(4).YLimits = [-2 2];
    xlabel("Time [s]");
end


%% Detrend raw data
for i = 1:5
    Detrend_Data{i} = detrend(table2array(Data{i}(:,2:5)));
end

% Plot the envelope
for i = 1:5
    figure,
    for k = 1:4
        sub(k) = subplot(4,1,k);
        plot(Detrend_Data{i}(:,k));
        title(Muscles(k));
        ylim([-2 2]);
    end
    xlabel("Time [s]");
    suptitle(Sheet(i));
    P2 = get(sub(2), 'position');
    P3 = get(sub(3), 'position');
    height = P2(2) + P2(4) - P3(2);
    AX = axes('position',[P3(1) P3(2) P3(3) height], 'visible','off'); 
    ylabel('Amplitude [V]','visible','on');
end


%% Power spectrum
for i = 1:5
    fig4 = figure;
    for k = 1:4
        Mat = Detrend_Data{i}(:,k);
        [P,f] = pspectrum(Mat,2000);
        sub(k) = subplot(4,1,k);
        plot(f,pow2db(P));
        title(Muscles(k));
    end
    xlabel("Frequency");
    suptitle(Sheet(i));
    P2 = get(sub(2), 'position');
    P3 = get(sub(3), 'position');
    height = P2(2) + P2(4) - P3(2);
    AX = axes('position',[P3(1) P3(2) P3(3) height], 'visible','off'); 
    ylabel('Power spectrum [dB]','visible','on');
end

saveas(fig4,"Power spectrum R Biceps.png")


%% Filter the data
fs = 2000;
[b, a] = butter(2,[10/(fs/2) 500/(fs/2)],'bandpass');
for i = 1:5
    for k = 1:4
        Mat = Detrend_Data{i}(:,k);
        Filter(:,k) = filtfilt(b,a,Mat);
    end
    Filtered_data{i} = Filter;
    Filter = [];
    Mat = [];
end

% Plot the filtered data
for i = 1:5
    figure,
    for k = 1:4
        sub(k) = subplot(4,1,k);
        plot(Filtered_data{i}(:,k));
        title(Muscles(k));
        ylim([-2 2]);
    end
    xlabel("Time [s]");
    suptitle(Sheet(i));
    P2 = get(sub(2), 'position');
    P3 = get(sub(3), 'position');
    height = P2(2) + P2(4) - P3(2);
    AX = axes('position',[P3(1) P3(2) P3(3) height], 'visible','off'); 
    ylabel('Amplitude [V]','visible','on');
end


%% Rectify filtered data
for i = 1:5
    Rec_filtered_data{i} = abs(Filtered_data{i});
end

% Plot the rectified data
for i = 1:5
    figure,
    for k = 1:4
        sub(k) = subplot(4,1,k);
        plot(Rec_filtered_data{i}(:,k));
        title(Muscles(k));
        ylim([-2 2]);
    end
    xlabel("Time [s]");
    suptitle(Sheet(i));
    P2 = get(sub(2), 'position');
    P3 = get(sub(3), 'position');
    height = P2(2) + P2(4) - P3(2);
    AX = axes('position',[P3(1) P3(2) P3(3) height], 'visible','off'); 
    ylabel('Amplitude [V]','visible','on');
end


%% Apply moveing average
for i = 1:5
    Movav_data{i} = movmean(Rec_filtered_data{i},100,1);
end

% Plot the data
for i = 1:5
    figure,
    for k = 1:4
        sub(k) = subplot(4,1,k);
        plot(Movav_data{i}(:,k));
        title(Muscles(k));
        ylim([0 0.6]);
    end
    xlabel("Time [s]");
    suptitle(Sheet(i));
    P2 = get(sub(2), 'position');
    P3 = get(sub(3), 'position');
    height = P2(2) + P2(4) - P3(2);
    AX = axes('position',[P3(1) P3(2) P3(3) height], 'visible','off'); 
    ylabel('Amplitude [V]','visible','on');
end


%% Save figure for presentation
fig1 = figure;
plot(Data{1}.R_Biceps);
ylabel("Amplitude [V]");
xlabel("Time [ms]");
title("EMG on right bicep femoris");

saveas(fig1,"Raw EMG R Biceps.png");


fig2 = figure;
plot(Movav_data{1}(:,1));
xlabel("Time [ms]");
ylabel("Amplitude [V]");
title("EMG on right bicep femoris");

saveas(fig2,"Enveloped EMG R Biceps.png");


fig3 = figure;
plot(Detrend_Data{1}(:,1));
xlabel("Time [ms]");
ylabel("Amplitude [V]");
title("EMG on right bicep femoris");

saveas(fig3,"Detrended EMG R Biceps.png");


fig5 = figure;
plot(Detrend_Data{1}(:,1));
xlabel("Time [ms]");
ylabel("Amplitude [V]");
title("EMG on right bicep femoris");

saveas(fig5,"Detrended EMG R Biceps.png");


fig6 = figure;
plot(Filtered_data{1}(:,1));
xlabel("Time [ms]");
ylabel("Amplitude [V]");
title("EMG on right bicep femoris");

saveas(fig6,"Filtered EMG R Biceps.png");


fig7 = figure;
plot(Rec_filtered_data{1}(:,1));
xlabel("Time [ms]");
ylabel("Amplitude [V]");
title("EMG on right bicep femoris");

saveas(fig7,"Rectified EMG R Biceps.png");


%% TKEO (Teager-Kaiser energy operator)
for i = 1:5
    Mat = Filtered_data{i};
    for j = 1:4
        Mus = Mat(:,j);
        Mus(2:end-1) = Mus(2:end-1).^2-Mus(1:end-2).*Mus(3:end);
        All(:,j) = Mus;
        Mus = [];
    end
    TKEO{i} = All;
    Mat = [];
    All = [];
end

% Plot data
for i = 1:5
    figure,
    for k = 1:4
        sub(k) = subplot(4,1,k);
        plot(TKEO{i}(:,k));
        title(Muscles(k));
        ylim([-1 1]);
    end
    xlabel("Time [ms]");
    suptitle(Sheet(i));
    P2 = get(sub(2), 'position');
    P3 = get(sub(3), 'position');
    height = P2(2) + P2(4) - P3(2);
    AX = axes('position',[P3(1) P3(2) P3(3) height], 'visible','off'); 
    ylabel('Energy','visible','on');
end


%% Low pass filter
[b_TKEO,a_TKEO] = butter(2,50/(fs/2),"low");
for i = 1:5
    for k = 1:4
        Mat = TKEO{i}(:,k);
        Low(:,k) = filtfilt(b_TKEO,a_TKEO,Mat);
    end
    Low_TKEO{i} = Low;
    Low = [];
    Mat = [];
end


% Plot data
for i = 1:5
    figure,
    for k = 1:4
        sub(k) = subplot(4,1,k);
        plot(Low_TKEO{i}(:,k));
        title(Muscles(k));
        ylim([-0.5 0.5]);
    end
    xlabel("Time [ms]");
    suptitle(Sheet(i));
    P2 = get(sub(2), 'position');
    P3 = get(sub(3), 'position');
    height = P2(2) + P2(4) - P3(2);
    AX = axes('position',[P3(1) P3(2) P3(3) height], 'visible','off'); 
    ylabel('Energy','visible','on');
end


%% Rectify the data
for i = 1:5
    Rec_Low_TKEO_data{i} = abs(Low_TKEO{i});
end


%% Find Muscle on and off (Based on research paper)
for i = 1:5
    for j = 1:4
        Mat = Rec_Low_TKEO_data{i}(:,j);
        Baseline = Rec_Low_TKEO_data{i}(2:1000,j);
        T(i,j) = mean(Baseline)+20*std(Baseline);
        On(i,j) = find(Mat(2:end-1) > T(i,j),1,"first");
        Off(i,j) = find(Mat(2:end-1) > T(i,j),1,"last");
    end   
end


%% Find Muscle on and off (Based on research paper without TKEO)
for i = 1:5
    for j = 1:4
        Mat = Filtered_data{i}(:,j);
        Baseline = Filtered_data{i}(2:1000,j);
        T(i,j) = mean(Baseline)+10*std(Baseline);
        On(i,j) = find(Mat(2:end-1) > T(i,j),1,"first");
        Off(i,j) = find(Mat(2:end-1) > T(i,j),1,"last");
    end   
end


%% Find Muscle on and off (Adjusted)
for i = 1:5
    for j = 1:4
        Mat = TKEO{i}(:,j);
        T(i,j) = max(Mat)*0.02;
        On(i,j) = find(Mat(2:end-1) > T(i,j),1,"first");
        Off(i,j) = find(Mat(2:end-1) > T(i,j),1,"last");
    end   
end


%% Check muscle on and off in filtered data and envelope
for i = 3
    figX = figure;
    for k = 1:4
        sub(k) = subplot(4,1,k);
        plot(Filtered_data{i}(:,k)),hold on;
        plot(Movav_data{i}(:,k),'r'),hold on;
        X1 = xline(On(i,k));
        X1.LineWidth = 2;
        X2 = xline(Off(i,k));
        X2.LineWidth = 2;
        yline(0);
        title(Muscles(k));
        ylim([-1 1]);
    end
    xlabel("Time [ms]");
    suptitle(Sheet(i));
    P2 = get(sub(2), 'position');
    P3 = get(sub(3), 'position');
    height = P2(2) + P2(4) - P3(2);
    AX = axes('position',[P3(1) P3(2) P3(3) height], 'visible','off'); 
    ylabel('Amplitude','visible','on');
end

saveas(figX,"With TKEO.png");

%% find duration
Duration = Off - On;

% Plot
fig10 = figure;
bar(Duration);
legend(Muscles);
xlabel('Trials');
ylabel("Time [ms]");
title("Duration of muscle activity");

saveas(fig10,"EMG duration.png");


%% Plot Muscle on and off with duration
Y = 4:-1:1;
fig11 = figure;
for i = 1:5
    S{i} = subplot(5,1,i);
    for k = 1:4
        plot([On(i,k) On(i,k)+Duration(i,k)],[Y(k) Y(k)]), hold on;       
    end
    ylabel(strcat("Trial ",string(i)),"Rotation",0,"Position",[-2000 2.5]);
    ylim([0 5]);
    xlim([0 30000]);
    legend(Muscles,'Location',"eastoutside");
end
xlabel("Time [ms]");
title(S{1},"Muscle on and off with duration");

saveas(fig11,"Muscle on and off with dur.png");


%% Plot for presentation
fig8 = figure;
plot(TKEO{1}(:,1));
xlabel("Time [ms]");
ylabel("Energy");
title("TKEO of right bicep femoris");

saveas(fig8,"TKEO R Bicep.png");


fig9 = figure;
plot(Filtered_data{2}(:,1)),hold on;
plot(Movav_data{2}(:,1),'r'),hold on;
X1 = xline(On(2,1));
X1.LineWidth = 2;
X2 = xline(Off(2,1));
X2.LineWidth = 2;
yline(0);
title(Muscles(1));
ylim([-1.5 1.5]);

saveas(fig9,"Muscle on and off.png");


%% Amplitude analysis

%% Plot envelope trial by trial
for i = 1:5
    figure;
    Envelope = Movav_data{i};
    for k = 1:4
        plot(On(i,k):Off(i,k),Envelope(On(i,k):Off(i,k),k)),hold on;
    end
    legend(Muscles,"Location","bestoutside");
    xlabel('Time [ms]');
    ylabel("Amplitude [V]");
    title(strcat("Trial ",string(i)));
end



%% Plot envelope muscle by muscle
for i = 1:5
    R_Biceps{i} = Movav_data{i}(:,1);
    R_Semi{i} = Movav_data{i}(:,2);
    L_Biceps{i} = Movav_data{i}(:,3);
    L_Semi{i} = Movav_data{i}(:,4);
end

Legend = ["Trial 1" "Trial 2" "Trial 3" "Trial 4" "Trial 5"];

figure;
for i = 1:5
    M = R_Biceps{i};
    plot(M(On(i,1):Off(i,1))),hold on;
end
title("Right bicep femoris");
legend(Legend);
xlabel("Time [ms]");
ylabel("Amplitude [V]");

figure;
for i = 1:5
    M = R_Semi{i};
    plot(M(On(i,2):Off(i,2))),hold on;
end
title("Right semitendinosus");
legend(Legend);
xlabel("Time [ms]");
ylabel("Amplitude [V]");

figure;
for i = 1:5
    M = L_Biceps{i};
    plot(M(On(i,3):Off(i,3))),hold on;
end
title("Left bicep femoris");
legend(Legend);
xlabel("Time [ms]");
ylabel("Amplitude [V]");

figure;
for i = 1:5
    M = R_Semi{i};
    plot(M(On(i,4):Off(i,4))),hold on;
end
title("Left semitendinosus");
legend(Legend);
xlabel("Time [ms]");
ylabel("Amplitude [V]");


%% Mean amplitude analysis
for i = 1:5
    Envelope = Movav_data{i};
    for k = 1:4
        Mean(i,k) = mean(Envelope(On(i,k):Off(i,k),k));
    end
end

% Plot
fig12 = figure;
bar(Mean);
legend(Muscles,"Location","bestoutside");
xlabel('Trials');
ylabel("Amplitude [V]");
title("Mean amplitude of muscle activity");

saveas(fig12,"EMG mean amplitude.png");


%% Peak amplitude analysis
for i = 1:5
    Envelope = Movav_data{i};
    for k = 1:4
        Peak(i,k) = max(Envelope(On(i,k):Off(i,k),k));
    end
end

% Plot
fig13 = figure;
bar(Peak);
legend(Muscles,"Location","bestoutside");
xlabel('Trials');
ylabel("Amplitude [V]");
title("Peak amplitude of muscle activity");

saveas(fig13,"EMG peak amplitude.png");


%% Integral amplitude analysis
for i = 1:5
    Envelope = Movav_data{i};
    for k = 1:4
        En_20 = Duration(i,k)*0.2;
        En_50 = Duration(i,k)*0.5;
        En_80 = Duration(i,k)*0.8;
        AUC_20(i,k) = trapz(Envelope(On(i,k)+En_20-1000:On(i,k)+En_20+1000,k));
        AUC_50(i,k) = trapz(Envelope(On(i,k)+En_50-1000:On(i,k)+En_50+1000,k));
        AUC_80(i,k) = trapz(Envelope(On(i,k)+En_80-1000:On(i,k)+En_80+1000,k));
    end
end


% Demo plot
fig14 = figure;
plot(On(1,1):Off(1,1),Movav_data{1}(On(1,1):Off(1,1),1)),hold on;
A1 = area(On(1,1)+Duration(1,1)*0.2-1000:On(1,1)+Duration(1,1)*0.2+1000,...
    Movav_data{1}(On(1,1)+Duration(1,1)*0.2-1000:On(1,1)+Duration(1,1)*0.2+1000));
A2 = area(On(1,1)+Duration(1,1)*0.5-1000:On(1,1)+Duration(1,1)*0.5+1000,...
    Movav_data{1}(On(1,1)+Duration(1,1)*0.5-1000:On(1,1)+Duration(1,1)*0.5+1000));
A3 = area(On(1,1)+Duration(1,1)*0.8-1000:On(1,1)+Duration(1,1)*0.8+1000,...
    Movav_data{1}(On(1,1)+Duration(1,1)*0.8-1000:On(1,1)+Duration(1,1)*0.8+1000));
title("Area under the curve");
legend([A1 A2 A3], {"20%","50%","80%"});
ylabel("Amplitude [V]");
xlabel("Time [ms]");

saveas(fig14,"Demo integral EMG.png");


% Plot 
Xlab = ["20%" "50%" "80%"];
fig15 = figure;
bar([AUC_20(:,1)'; AUC_50(:,1)'; AUC_80(:,1)']);
title("Right bicep femoris");
xticklabels(Xlab);
ylabel("Impluse [V*t]");
legend(Legend,"Location","bestoutside");

saveas(fig15,"R bicep integral EMG.png");

figure;
bar([AUC_20(:,2)'; AUC_50(:,2)'; AUC_80(:,2)']);
title("Right semitendinosus");
xticklabels(Xlab);
ylabel("Impluse [V*t]");
legend(Legend,"Location","bestoutside");

figure;
bar([AUC_20(:,3)'; AUC_50(:,3)'; AUC_80(:,3)']);
title("Left bicep femoris");
xticklabels(Xlab);
ylabel("Impulse [V*t]");
legend(Legend,"Location","bestoutside");

figure;
bar([AUC_20(:,4)'; AUC_50(:,4)'; AUC_80(:,4)']);
title("Left semitendinosus");
xticklabels(Xlab);
ylabel("Impluse [V*t]");
legend(Legend,"Location","bestoutside");


%% Frequency analysis

%% FFT (Fast Fourier Transform) muscle by muscle
for i = 1:5
    figure;
    for k = 1:4
        sub(k) = subplot(4,1,k);
        Y = fft(Filtered_data{i}(On(i,k):Off(i,k),k));
        P2 = abs(Y); 
        P1 = P2(1:length(Y)/2+1); % Half of signal length + 1 cz x axis which is frequency starts from 0
        f = fs*(0:(length(Y)/2))/length(Y); % Convert bins to Hz
        plot(f,P1);
        Y = [];
        P2 = [];
        P1 = [];
    end
    xlabel("Frequency [Hz]");
    suptitle(Sheet(i));
    P2 = get(sub(2), 'position');
    P3 = get(sub(3), 'position');
    height = P2(2) + P2(4) - P3(2);
    AX = axes('position',[P3(1) P3(2) P3(3) height], 'visible','off'); 
    ylabel('Amplitude','visible','on');
end


% FFT trial by trial
for i = 1:5
    R_Biceps{i} = fft(Filtered_data{i}(On(i,1):Off(i,1),1));
    R_Semi{i} = fft(Filtered_data{i}(On(i,2):Off(i,2),2));
    L_Biceps{i} = fft(Filtered_data{i}(On(i,3):Off(i,3),3));
    L_Semi{i} = fft(Filtered_data{i}(On(i,4):Off(i,4),4));
end

figure;
for i = 1:5
    S(i) = subplot(5,1,i);
    P2 = abs(R_Biceps{i});
    P1 = P2(1:length(P2)/2+1); 
    f = fs*(0:(length(P2)/2))/length(P2);
    plot(f,P1);
    ylabel(strcat("Trial ",string(i)));
end
xlabel("Frequency [Hz]");
title(S(1),"Right bicep femoris");

figure;
for i = 1:5
    S(i) = subplot(5,1,i);
    P2 = abs(R_Semi{i});
    P1 = P2(1:length(P2)/2+1); 
    f = fs*(0:(length(P2)/2))/length(P2);
    plot(f,P1);
    ylabel(strcat("Trial ",string(i)));
end
xlabel("Frequency [Hz]");
title(S(1),"Right semi-tendinosus");

figure;
for i = 1:5
    S(i) = subplot(5,1,i);
    P2 = abs(L_Biceps{i});
    P1 = P2(1:length(P2)/2+1); 
    f = fs*(0:(length(P2)/2))/length(P2);
    plot(f,P1);
    ylabel(strcat("Trial ",string(i)));
end
xlabel("Frequency [Hz]");
title(S(1),"Left bicep femoris");

figure;
for i = 1:5
    S(i) = subplot(5,1,i);
    P2 = abs(L_Semi{i});
    P1 = P2(1:length(P2)/2+1); 
    f = fs*(0:(length(P2)/2))/length(P2);
    plot(f,P1);
    ylabel(strcat("Trial ",string(i)));
end
xlabel("Frequency [Hz]");
title(S(1),"Left semi-tendinosus");


%% Mean frequency
for i = 1:5
    for k = 1:4
        Freq_mean(i,k) = meanfreq(Filtered_data{i}(On(i,k):Off(i,k),k),fs);
    end
end

% Check it on plot
for i = 1:5
    figure;
    for k = 1:4
        sub(k) = subplot(4,1,k);
        Y = fft(Filtered_data{i}(On(i,k):Off(i,k),k));
        P2 = abs(Y); 
        P1 = P2(1:length(Y)/2+1); % Half of signal length + 1 cz x axis which is frequency starts from 0
        f = fs*(0:(length(Y)/2))/length(Y); % Convert bins to Hz
        plot(f,P1),hold on;
        xline(Freq_mean(i,k),'LineWidth',2);
        Y = [];
        P2 = [];
        P1 = [];
    end
    xlabel("Frequency [Hz]");
    suptitle(Sheet(i));
    P2 = get(sub(2), 'position');
    P3 = get(sub(3), 'position');
    height = P2(2) + P2(4) - P3(2);
    AX = axes('position',[P3(1) P3(2) P3(3) height], 'visible','off'); 
    ylabel('Amplitude','visible','on');
end

% Bar plot
fig_freq4 = figure;
bar(Freq_mean);
xlabel("Trial");
ylabel("Frequency [Hz]");
legend(Muscles,'Location',"bestoutside");
title("Mean frequency analysis");

saveas(fig_freq4,"Mean freq.png");


%% Median frequency
for i = 1:5
    for k = 1:4
        Freq_med(i,k) = medfreq(Filtered_data{i}(On(i,k):Off(i,k),k),fs);
    end
end

% Check it on plot
for i = 1:5
    figure;
    for k = 1:4
        sub(k) = subplot(4,1,k);
        Y = fft(Filtered_data{i}(On(i,k):Off(i,k),k));
        P2 = abs(Y); 
        P1 = P2(1:length(Y)/2+1); % Half of signal length + 1 cz x axis which is frequency starts from 0
        f = fs*(0:(length(Y)/2))/length(Y); % Convert bins to Hz
        plot(f,P1),hold on;
        xline(Freq_med(i,k),'LineWidth',2);
        Y = [];
        P2 = [];
        P1 = [];
    end
    xlabel("Frequency [Hz]");
    suptitle(Sheet(i));
    P2 = get(sub(2), 'position');
    P3 = get(sub(3), 'position');
    height = P2(2) + P2(4) - P3(2);
    AX = axes('position',[P3(1) P3(2) P3(3) height], 'visible','off'); 
    ylabel('Amplitude','visible','on');
end

% Bar plot
fig_freq5 = figure;
bar(Freq_med);
xlabel("Trial");
ylabel("Frequency [Hz]");
legend(Muscles,'Location',"bestoutside");
title("Median frequency analysis");

saveas(fig_freq5,"Median freq.png");


%% Median frequency within a muscle
for i = 1:5
    EMG = Filtered_data{i};
    for k = 1:4
        EMG_20 = Duration(i,k)*0.2;
        EMG_50 = Duration(i,k)*0.5;
        EMG_80 = Duration(i,k)*0.8;
        Freq_med_20(i,k) = medfreq(EMG(On(i,k)+EMG_20-1000:On(i,k)+EMG_20+1000,k),fs);
        Freq_med_50(i,k) = medfreq(EMG(On(i,k)+EMG_50-1000:On(i,k)+EMG_50+1000,k),fs);
        Freq_med_80(i,k) = medfreq(EMG(On(i,k)+EMG_80-1000:On(i,k)+EMG_80+1000,k),fs);
    end
end


% Plot 
Legend = ["Trial 1" "Trial 2" "Trial 3" "Trial 4" "Trial 5"];
Xlab = ["20%" "50%" "80%"];
fig_freq6 = figure;
bar([Freq_med_20(:,1)'; Freq_med_50(:,1)'; Freq_med_80(:,1)']);
title("Right bicep femoris");
xticklabels(Xlab);
ylabel("Impluse [V*t]");
legend(Legend,"Location","bestoutside");

saveas(fig_freq6,"Med freq in R biceps.png");


figure;
bar([Freq_med_20(:,2)'; Freq_med_50(:,2)'; Freq_med_80(:,2)']);
title("Right semitendinosus");
xticklabels(Xlab);
ylabel("Frequency [Hz]");
legend(Legend,"Location","bestoutside");

figure;
bar([Freq_med_20(:,3)'; Freq_med_50(:,3)'; Freq_med_80(:,3)']);
title("Left bicep femoris");
xticklabels(Xlab);
ylabel("Frequency [Hz]");
legend(Legend,"Location","bestoutside");

figure;
bar([Freq_med_20(:,4)'; Freq_med_50(:,4)'; Freq_med_80(:,4)']);
title("Left semitendinosus");
xticklabels(Xlab);
ylabel("Frequency [Hz]");
legend(Legend,"Location","bestoutside");


%% STFT (Short Time Fourier Transform)
for i = 1:5
    figure;
    for k = 1:4
        subplot(2,2,k);
        spectrogram(Filtered_data{i}(On(i,k):Off(i,k),k),[],[],[],2000,'yaxis');
        title(Muscles(k));
    end
end


%% Plot for presentation
fig_freq1 = figure;
Y = fft(Filtered_data{1}(On(1,1):Off(1,1),1));
P2 = abs(Y); 
P1 = P2(1:length(Y)/2+1); % Half of signal length + 1 cz x axis which is frequency starts from 0
f = fs*(0:(length(Y)/2))/length(Y); % Convert bins to Hz
plot(f,P1);
xlabel("Frequency [Hz]");
title("Right bicep femoris in trial 1");
ylabel('Amplitude');

saveas(fig_freq1,"FFT R biceps.png");


fig_freq2 = figure;
Y = fft(Filtered_data{1}(On(1,1):Off(1,1),1));
P2 = abs(Y); 
P1 = P2(1:length(Y)/2+1); % Half of signal length + 1 cz x axis which is frequency starts from 0
f = fs*(0:(length(Y)/2))/length(Y); % Convert bins to Hz
plot(f,P1);
xline(Freq_mean(1,1),'LineWidth',2);
xlabel("Frequency [Hz]");
title("Right bicep femoris in trial 1");
ylabel('Amplitude');

saveas(fig_freq2,"FFT R biceps with mean freq.png");


fig_freq3 = figure;
Y = fft(Filtered_data{1}(On(1,1):Off(1,1),1));
P2 = abs(Y); 
P1 = P2(1:length(Y)/2+1); % Half of signal length + 1 cz x axis which is frequency starts from 0
f = fs*(0:(length(Y)/2))/length(Y); % Convert bins to Hz
plot(f,P1);
xline(Freq_med(1,1),'LineWidth',2);
xlabel("Frequency [Hz]");
title("Right bicep femoris in trial 1");
ylabel('Amplitude');

saveas(fig_freq3,"FFT R biceps with med freq.png");


fig_freq7 = figure;
spectrogram(Filtered_data{1}(On(1,1):Off(1,1),1),1000,100,[],2000,'yaxis');
view(45,45);
title("Right bicep femoris");

saveas(fig_freq7,"STFT R bicep.png");
        
        
        

